@@ -7,5 +7,17 @@ from .bamboo import Bamboo
 from .crowd import Crowd
 from .service_desk import ServiceDesk
 from .marketplace import MarketPlace
+from .jira8 import Jira8
 
-__all__ = ['Confluence', 'Jira', 'Bitbucket', 'Portfolio', 'Bamboo', 'Stash', 'Crowd', 'ServiceDesk', 'MarketPlace']
+__all__ = [
+    'Confluence',
+    'Jira',
+    'Bitbucket',
+    'Portfolio',
+    'Bamboo',
+    'Stash',
+    'Crowd',
+    'ServiceDesk',
+    'MarketPlace',
+    'Jira8'
+]
