@@ -5,8 +5,9 @@ from six.moves.urllib.parse import urlencode
 import requests
 from oauthlib.oauth1 import SIGNATURE_RSA
 from requests_oauthlib import OAuth1
+from atlassian.request_utils import get_default_logger
 
-log = logging.getLogger(__name__)
+log = get_default_logger(__name__)
 
 
 class AtlassianRestAPI(object):
@@ -17,7 +18,7 @@ class AtlassianRestAPI(object):
                           'X-Atlassian-Token': 'no-check'}
 
     def __init__(self, url, username=None, password=None, timeout=60, api_root='rest/api', api_version='latest',
-                 verify_ssl=True, session=None, oauth=None, cookies=None):
+                 verify_ssl=True, session=None, oauth=None, cookies=None, advanced_mode=None):
         self.url = url
         self.username = username
         self.password = password
@@ -26,6 +27,7 @@ class AtlassianRestAPI(object):
         self.api_root = api_root
         self.api_version = api_version
         self.cookies = cookies
+        self.advanced_mode = advanced_mode
         if session is None:
             self._session = requests.Session()
         else:
@@ -38,7 +40,7 @@ class AtlassianRestAPI(object):
     def _create_basic_session(self, username, password):
         self._session.auth = (username, password)
 
-    def _create_oauth_session(self, oauth_dict, timeout=60):
+    def _create_oauth_session(self, oauth_dict):
         oauth = OAuth1(oauth_dict['consumer_key'],
                        rsa_key=oauth_dict['key_cert'], signature_method=SIGNATURE_RSA,
                        resource_owner_key=oauth_dict['access_token'],
@@ -84,8 +86,8 @@ class AtlassianRestAPI(object):
             url_link += '/'
         return url_link
 
-    def request(self, method='GET', path='/', data=None, flags=None, params=None, headers=None, files=None,
-                trailing=None):
+    def request(self, method='GET', path='/', data=None, flags=None, params=None, headers=None,
+                files=None, trailing=None):
         """
 
         :param method:
@@ -118,7 +120,9 @@ class AtlassianRestAPI(object):
             timeout=self.timeout,
             verify=self.verify_ssl,
             files=files
-        )
+        )       
+        if self.advanced_mode:
+            return response
         try:
             if response.text:
                 response_content = response.json()
@@ -183,17 +187,23 @@ class AtlassianRestAPI(object):
                 return answer.text
 
     def post(self, path, data=None, headers=None, files=None, params=None, trailing=None):
+        response = self.request('POST', path=path, data=data, headers=headers, files=files, params=params,
+                                trailing=trailing)
+        if self.advanced_mode:
+            return response
         try:
-            return self.request('POST', path=path, data=data, headers=headers, files=files, params=params,
-                                trailing=trailing).json()
+            return response.json()
         except ValueError:
             log.debug('Received response with no content')
             return None
 
     def put(self, path, data=None, headers=None, files=None, trailing=None, params=None):
+        response = self.request('PUT', path=path, data=data, headers=headers, files=files, params=params,
+                                trailing=trailing)
+        if self.advanced_mode:
+            return response
         try:
-            return self.request('PUT', path=path, data=data, headers=headers, files=files, params=params,
-                                trailing=trailing).json()
+            return response.json()
         except ValueError:
             log.debug('Received response with no content')
             return None
